@@ -3,7 +3,7 @@
 #' Functions that have passed on to the function afterlife.
 #' Their successors are also listed.
 #'
-#' @param object,... Ignored arguments.
+#' @param object,x,... Ignored arguments.
 #'
 #' @details
 #' \code{calculateQCMetrics} is succeeded by \code{\link{perCellQCMetrics}} and \code{\link{perFeatureQCMetrics}}.
@@ -11,6 +11,10 @@
 #' \code{normalize} is succeeded by \code{\link{logNormCounts}}.
 #'
 #' \code{centreSizeFactors} has no replacement - the \pkg{SingleCellExperiment} is removing support for multiple size factors, so this function is now trivial.
+#' 
+#' \code{runDiffusionMap} and \code{calculateDiffusionMap} have no replacement.
+#' \pkg{destiny} is no longer on Bioconductor. You can calculate a diffusion map
+#' yourself, and add it to a \code{reducedDim} field, if you so wish.
 #'
 #' @return All functions error out with a defunct message pointing towards its descendent (if available).
 #'
@@ -39,3 +43,23 @@ setMethod("normalize", "SingleCellExperiment", function(object, ...) {
 centreSizeFactors <- function(...) {
     .Defunct()
 }
+
+#' @export
+#' @rdname defunct
+setGeneric("calculateDiffusionMap", function(x, ...) {
+    standardGeneric("calculateDiffusionMap")
+})
+
+#' @export
+#' @rdname defunct
+setMethod("calculateDiffusionMap", "ANY", function(x, ...) {
+    .Defunct()
+})
+
+#' @export
+#' @rdname defunct
+#' @importFrom SingleCellExperiment reducedDim<-
+runDiffusionMap <- function(...) {
+    .Defunct()
+}
+
