@@ -171,3 +171,38 @@ test_that("gg functions work as expected", {
     expect_s3_class(gg, "ggplot")
 })
 
+
+set.seed(1000009)
+test_that("tricube calculations work correctly", {
+    A <- matrix(runif(1000), ncol=20)
+    self <- BiocNeighbors::findKNN(A, k=10)
+
+    out <- scater:::.compute_tricube_average(A, indices=self$index, distances=self$distance)
+    expect_identical(dim(out), dim(A)) 
+
+    # Logic checks.
+    out <- scater:::.compute_tricube_average(A, indices=self$index[,1,drop=FALSE], distances=self$distance[,1,drop=FALSE])
+    expect_identical(out, A[self$index[,1],])
+
+    uni.dist <- self$distance
+    uni.dist[] <- 1
+    out <- scater:::.compute_tricube_average(A, indices=self$index, distances=uni.dist)
+    assembly <- A
+    for (i in seq_len(nrow(assembly))) {
+        assembly[i,] <- colMeans(A[self$index[i,],])
+    }
+    expect_equal(out, assembly)
+
+    uni.index <- self$index
+    uni.index[] <- seq_len(nrow(A))
+    out <- scater:::.compute_tricube_average(A, indices=uni.index, distances=self$distance)
+    expect_equal(out, A)
+
+    # Silly input checks.
+    out <- scater:::.compute_tricube_average(A, indices=self$index[,0], distances=self$distance[,0])
+    expect_identical(dim(out), dim(A))
+    expect_true(all(out==0))
+
+    out <- scater:::.compute_tricube_average(A[0,], indices=self$index[0,], distances=self$distance[0,])
+    expect_identical(dim(out), c(0L, ncol(A)))
+})
